@@ -16,8 +16,8 @@ running Editra.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: Editra.py 66186 2010-11-18 04:14:45Z CJP $"
-__revision__ = "$Revision: 66186 $"
+__svnid__ = "$Id: Editra.py 66551 2011-01-03 22:08:38Z CJP $"
+__revision__ = "$Revision: 66551 $"
 
 #--------------------------------------------------------------------------#
 # Dependencies
@@ -820,6 +820,9 @@ def InitConfig():
         if wx.Platform == '__WXMSW__':
             profiler.Profile_Set('EOL_MODE', ed_glob.EOL_MODE_CRLF)
             profiler.Profile_Set('ICONSZ', (16, 16))
+        elif wx.Platform == '__WXMAC__':
+            # Default to 32x32 toolbar icons on OSX
+            profiler.Profile_Set('ICONSZ', (32, 32))
 
     #---- Profile Loaded / Installed ----#
 
