@@ -14,11 +14,12 @@ Base class for autocompletion providers to implement the completion interface.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: completer.py 62467 2009-10-22 02:10:51Z CJP $"
-__revision__ = "$Revision: 62467 $"
+__svnid__ = "$Id: completer.py 66216 2010-11-19 22:59:05Z CJP $"
+__revision__ = "$Revision: 66216 $"
 
-__all__ = [ 'IMG_FUNCTION', 'IMG_METHOD', 'IMG_CLASS', 'IMG_ATTRIBUTE',
-            'IMG_VARIABLE', 'IMG_ELEMENT', 'IMG_PROPERTY', 'BaseCompleter' ]
+__all__ = [ 'TYPE_FUNCTION', 'TYPE_METHOD', 'TYPE_CLASS', 'TYPE_ATTRIBUTE',
+            'TYPE_VARIABLE', 'TYPE_ELEMENT', 'TYPE_PROPERTY', 'TYPE_UNKNOWN',
+            'BaseCompleter', 'Symbol', 'CreateSymbols' ]
 
 #--------------------------------------------------------------------------#
 # Imports
@@ -27,30 +28,101 @@ import wx
 #--------------------------------------------------------------------------#
 
 # Image Type Ids
-IMG_FUNCTION, \
-IMG_METHOD, \
-IMG_CLASS, \
-IMG_ATTRIBUTE, \
-IMG_PROPERTY, \
-IMG_VARIABLE, \
-IMG_ELEMENT  = range(1, 8)
+TYPE_FUNCTION, \
+TYPE_METHOD, \
+TYPE_CLASS, \
+TYPE_ATTRIBUTE, \
+TYPE_PROPERTY, \
+TYPE_VARIABLE, \
+TYPE_ELEMENT, \
+TYPE_UNKNOWN = range(1, 9)
+
+#--------------------------------------------------------------------------#
+class Symbol(object):
+    """ Defines a symbol as parsed by the autocompleter.
+    Symbols with the same name and different type are EQUAL
+    Symbol hash is based on symbol NAME
+    
+    """
+    # we create lots of these so use slots as a performance tweak
+    __slots__ = ('_name', '_type')
+
+    def __init__(self, name, symtype):
+        """ Constructor
+        @param name: Symbol name
+        @param symtype: Symbol type, one of the TYPE_FUNCTION ... TYPE_UNKNOWN range
+        
+        """
+        super(Symbol, self).__init__()
+
+        # Attributes
+        self._name = unicode(name)
+        self._type = symtype
+    
+    def __eq__(self, other):
+        return (self.Name == other.Name)
+
+    def __lt__(self, other):
+        return (self.Name < other.Name)
+
+    def __le__(self, other):
+        return (self.Name <= other.Name)
+
+    def __ne__(self, other):
+        return (self.Name != other.Name)
+
+    def __gt__(self, other):
+        return (self.Name > other.Name)
+
+    def __ge__(self, other):
+        return (self.Name >= other.Name)
+
+    # TODO: this task should probably be delegated to the ui
+    def __str__(self):
+        if self.Type != TYPE_UNKNOWN:
+            return u'?'.join([self.Name, unicode(self.Type)])
+        else:
+            return self.Name
+
+    def __hash__(self):
+        return hash(self.Name)
+    
+    @property
+    def Name(self):
+        return self._name
+
+    @property
+    def Type(self):
+        return self._type
+
+#--------------------------------------------------------------------------#
+
+def CreateSymbols(arglst, symtype=TYPE_UNKNOWN):
+    """Convert a list of strings to a list of Symbol objects
+    @param arglst: list of strings
+    @keyword symtype: TYPE_FOO 
+    @return: list of Symbols
+
+    """
+    return [ Symbol(obj, symtype) for obj in arglst ]
 
 #--------------------------------------------------------------------------#
 
 class BaseCompleter(object):
     """Base Autocomp provider class"""
     def __init__(self, parent):
-        """Initializes the autocompletion service
+        """Initializes the auto-completion service
         @param parent: parent of this service object
 
         """
-        object.__init__(self)
+        super(BaseCompleter, self).__init__()
 
         # Attributes
         self._buffer = parent
         self._log = wx.GetApp().GetLog()
         self._case_sensitive = False
         self._autocomp_after = False
+        self._choose_single = True
 
         self._autocomp_keys = list()
         self._autocomp_stop = u''
@@ -70,21 +142,22 @@ class BaseCompleter(object):
 
     def GetCallTip(self, command):
         """Returns the calltip string for a command
-        @param command: command to get callip for (string)
+        @param command: command to get calltip for (string)
         @return: string
 
         """
         return u''
 
-    #--- End override in subclass ----#
-
-    def GetAutoCompAfter(self):
-        """Should text insterted by autocomp be placed after the cursor
-        or before it.
-        @return: bool
+    def OnCompletionInserted(self, pos, text):
+        """Called by the buffer when an autocomp selection has been inserted.
+        The completer can override this method to 
+        @param pos: Position the caret was at before the insertion
+        @param text: text that was inserted at pos
 
         """
-        return self._autocomp_after
+        pass
+
+    #--- End override in subclass ----#
 
     def GetAutoCompKeys(self):
         """Returns the list of key codes for activating the autocompletion.
@@ -103,7 +176,7 @@ class BaseCompleter(object):
         """Is it a key combination that should allow completions to be shown
         @param evt: wx.KeyEvent
         @return: bool
-        @todo: this shoud probably be handled in edstc
+        @todo: this should probably be handled in ed_stc
 
         """
         if evt.ControlDown() and evt.GetKeyCode() == wx.WXK_SPACE:
@@ -182,14 +255,6 @@ class BaseCompleter(object):
         """
         return self._case_sensitive
 
-    def SetAutoCompAfter(self, after=False):
-        """Set if text insterted by autocomp should be placed after the cursor
-        or before it.
-        @keyword after: bool
-
-        """
-        self._autocomp_after = after
-
     def SetCaseSensitive(self, sensitive):
         """Set whether this completer is case sensitive or not
         @param sensitive: bool
@@ -197,6 +262,22 @@ class BaseCompleter(object):
         """
         self._case_sensitive = sensitive
 
+    def GetChooseSingle(self):
+        """Get whether the completer should automatically choose a selection
+        when there is only one symbol in the completion list.
+        @return: bool
+
+        """
+        return self._choose_single
+
+    def SetChooseSingle(self, single):
+        """Set whether the completer should automatically choose a selection
+        when there is only one symbol in the completion list.
+        @param single: bool
+
+        """
+        self._choose_single = single
+
     def ShouldCheck(self, cpos):
         """Should completions be attempted
         @param cpos: current buffer position
