@@ -61,8 +61,8 @@ Requirements:
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: outbuff.py 66333 2010-12-05 19:44:55Z CJP $"
-__revision__ = "$Revision: 66333 $"
+__svnid__ = "$Id: outbuff.py 66451 2010-12-26 16:11:56Z CJP $"
+__revision__ = "$Revision: 66451 $"
 
 __all__ = ["OutputBuffer", "OutputBufferEvent", "ProcessBufferMixin",
            "ProcessThread", "TaskThread", "OPB_STYLE_DEFAULT", "OPB_STYLE_INFO",
@@ -307,6 +307,7 @@ class OutputBuffer(wx.stc.StyledTextCtrl):
         self.DoHotSpotClicked(pos, self.LineFromPosition(pos))
 
     #---- Public Member Functions ----#
+
     def AppendUpdate(self, value):
         """Buffer output before adding to window. This method can safely be
         called from non gui threads to add updates to the buffer, that will
@@ -425,6 +426,13 @@ class OutputBuffer(wx.stc.StyledTextCtrl):
         """
         return wx.Colour(*self._colors['warnf'])
 
+    def GetUpdateQueue(self):
+        """Gets a copy of the current update queue"""
+        self._updating.acquire()
+        val = list(self._updates)
+        self._updating.release()
+        return val
+
     def IsRunning(self):
         """Return whether the buffer is running and ready for output
         @return: bool
@@ -847,24 +855,21 @@ class ProcessThread(threading.Thread):
         # TODO: See about supporting use_shell on Windows it causes lots of
         #       issues with gui apps and killing processes when it is True.
         if use_shell and subprocess.mswindows:
+            suinfo = subprocess.STARTUPINFO()
             # Don't set this flag if we are not using the shell on
             # Windows as it will cause any gui app to not show on the
             # display!
-            suinfo = subprocess.STARTUPINFO()
             #TODO: move this into common library as it is needed
             #      by most code that uses subprocess
-            if sys.platform.lower().startswith('win'):            
-                if hasattr(subprocess, 'STARTF_USESHOWWINDOW'):
-                    suinfo.dwFlags |= subprocess.STARTF_USESHOWWINDOW
-                else:
-                    try:
-                        from win32process import STARTF_USESHOWWINDOW
-                        suinfo.dwFlags |= STARTF_USESHOWWINDOW
-                    except ImportError:
-                        # Give up and try hard coded value from Windows.h
-                        suinfo.dwFlags |= 0x00000001
+            if hasattr(subprocess, 'STARTF_USESHOWWINDOW'):
+                suinfo.dwFlags |= subprocess.STARTF_USESHOWWINDOW
             else:
-                suinfo = None
+                try:
+                    from win32process import STARTF_USESHOWWINDOW
+                    suinfo.dwFlags |= STARTF_USESHOWWINDOW
+                except ImportError:
+                    # Give up and try hard coded value from Windows.h
+                    suinfo.dwFlags |= 0x00000001
         else:
             suinfo = None
         
