@@ -15,8 +15,8 @@ syntax highlighting of all supported filetypes.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_basestc.py 66083 2010-11-10 00:50:37Z CJP $"
-__revision__ = "$Revision: 66083 $"
+__svnid__ = "$Id: ed_basestc.py 66659 2011-01-08 20:30:35Z CJP $"
+__revision__ = "$Revision: 66659 $"
 
 #-----------------------------------------------------------------------------#
 # Imports
@@ -75,6 +75,7 @@ class EditraBaseStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
 
         self.vert_edit = vertedit.VertEdit(self)
         self._line_num = True # Show line numbers
+        self._last_cwidth = 1 # one pixel
 
         # Set Up Margins
         ## Outer Left Margin Bookmarks
@@ -97,19 +98,22 @@ class EditraBaseStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
             for keys in _GetMacKeyBindings():
                 self.CmdKeyAssign(*keys)
 
-        # Setup Autocomp images
+        # Setup Auto-comp images
         # TODO: should be called on theme change messages
         self.RegisterImages()
 
         # Event Handlers
+        self.Bind(wx.EVT_WINDOW_DESTROY, self.OnDestroy, self)
         self.Bind(wx.stc.EVT_STC_CHANGE, self.OnChanged)
         self.Bind(wx.stc.EVT_STC_MODIFIED, self.OnModified)
         self.Bind(wx.stc.EVT_STC_AUTOCOMP_SELECTION, self.OnAutoCompSel)
 
-    def __del__(self):
-        # Cleanup the file object callbacks
-        self.file.RemoveModifiedCallback(self.FireModified)
-        self.file.CleanUp()
+    def OnDestroy(self, evt):
+        if evt.GetId() == self.GetId():
+            # Cleanup the file object callbacks
+            self.file.RemoveModifiedCallback(self.FireModified)
+            self.file.CleanUp()
+        evt.Skip()
 
     #---- Public Methods ----#
 
@@ -493,7 +497,12 @@ class EditraBaseStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         if set_ext != u'':
             ext = set_ext.lower()
         else:
-            ext = self.file.GetExtension()
+            ext = self.file.GetExtension().lower()
+
+        if ext == u'':
+            fname = self.GetFileName()
+            ext = ebmlib.GetFileName(fname).lower()
+
         self.ClearDocumentStyle()
 
         # Configure Lexer from File Extension
@@ -506,12 +515,15 @@ class EditraBaseStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
             if interp != wx.EmptyString:
                 interp = interp.split(u"/")[-1]
                 interp = interp.strip().split()
-                if len(interp) and interp[-1][0] != "-":
+                if len(interp) and interp[-1][0] != u"-":
                     interp = interp[-1]
                 elif len(interp):
                     interp = interp[0]
                 else:
                     interp = u''
+                # TODO: should check user config to ensure the explict
+                #       extension is still associated with the expected
+                #       file type.
                 ex_map = { "python" : "py", "wish" : "tcl", "ruby" : "rb",
                            "bash" : "sh", "csh" : "csh", "perl" : "pl",
                            "ksh" : "ksh", "php" : "php", "booi" : "boo",
@@ -538,6 +550,7 @@ class EditraBaseStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
             #       for multibyte characters.
             line, col = self.GetCurLine()
             col = self.GetColumn(self.GetCurrentPos())
+        line = line.expandtabs(self.GetTabWidth())
         cmd_lmt = list(self._code['compsvc'].GetAutoCompStops() + \
                        self._code['compsvc'].GetAutoCompFillups())
         for key in self._code['compsvc'].GetAutoCompKeys():
@@ -688,14 +701,18 @@ class EditraBaseStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
             bMulti = sline != eline
         return bMulti
 
+    def CallTipCancel(self):
+        """Cancel any active calltip(s)"""
+        if self.CallTipActive():
+            super(EditraBaseStc, self).CallTipCancel()
+
     def CallTipShow(self, position, tip):
         """Show a calltip at the given position in the control
         @param position: int
         @param tip: unicode
 
         """
-        if self.CallTipActive():
-            self.CallTipCancel()
+        self.CallTipCancel()
         super(EditraBaseStc, self).CallTipShow(position, tip)
 
     def HidePopups(self):
@@ -703,8 +720,7 @@ class EditraBaseStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         if self.AutoCompActive():
             self.AutoCompCancel()
 
-        if self.CallTipActive():
-            self.CallTipCancel()
+        self.CallTipCancel()
 
     def InitCompleter(self):
         """(Re)Initialize a completer object for this buffer
@@ -1004,8 +1020,7 @@ class EditraBaseStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         @param command: command to  look for calltips for
 
         """
-        if self.CallTipActive():
-            self.CallTipCancel()
+        self.CallTipCancel()
 
         tip = self._code['compsvc'].GetCallTip(command)
         if len(tip):
