@@ -18,8 +18,8 @@ a gradient using system defined colors.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_cmdbar.py 61817 2009-09-03 01:19:51Z CJP $"
-__revision__ = "$Revision: 61817 $"
+__svnid__ = "$Id: ed_cmdbar.py 66482 2010-12-28 21:57:50Z CJP $"
+__revision__ = "$Revision: 66482 $"
 
 #--------------------------------------------------------------------------#
 # Imports
@@ -146,7 +146,7 @@ class CommandBarBase(eclib.ControlBar):
             self.ShowControl(ctrl.GetName(), not ctrl.IsShown())
             self.Layout()
 
-            # Update the persistant configuration
+            # Update the persistent configuration
             key = self.GetConfigKey()
             if key is not None:
                 cfg = Profile_Get('CTRLBAR', default=dict())
@@ -164,7 +164,7 @@ class CommandBarBase(eclib.ControlBar):
             self._menu = None
 
     def GetConfigKey(self):
-        """Get the key to use for the layout config persistance.
+        """Get the key to use for the layout config persistence.
         @return: string
         @note: override in subclasses
 
@@ -194,12 +194,13 @@ class CommandBarBase(eclib.ControlBar):
     def Hide(self):
         """Hides the control and notifies the parent
         @postcondition: commandbar is hidden
-        @todo: dont reference nb directly here
+        @todo: don't reference nb directly here
 
         """
         super(CommandBarBase, self).Hide()
         self._parent.SendSizeEvent()
-        self._parent.nb.GetCurrentCtrl().SetFocus()
+        nb = self._parent.GetNotebook()
+        nb.GetCurrentCtrl().SetFocus()
         return True
 
     def ShowControl(self, ctrl_name, show=True):
@@ -303,6 +304,7 @@ class SearchBar(CommandBarBase):
             self.ctrl.SetSizeHints(180, 16, 180, 16)
 
         # Event Handlers
+        self.Bind(wx.EVT_WINDOW_DESTROY, self.OnDestroy)
         self.Bind(wx.EVT_BUTTON, self.OnButton)
         self.Bind(wx.EVT_CHECKBOX, self.OnCheck)
         ed_msg.Subscribe(self.OnThemeChange, ed_msg.EDMSG_THEME_CHANGED)
@@ -313,9 +315,10 @@ class SearchBar(CommandBarBase):
         cfg = state.get(self.GetConfigKey(), dict())
         self.SetControlStates(cfg)
 
-    def __del__(self):
-        ed_msg.Unsubscribe(self.OnThemeChange)
-        self._sctrl.RemoveClient(self)
+    def OnDestroy(self, evt):
+        if evt.GetId() == self.GetId():
+            ed_msg.Unsubscribe(self.OnThemeChange)
+            self._sctrl.RemoveClient(self)
 
     def OnButton(self, evt):
         """Handle button clicks for the next/previous buttons
@@ -386,7 +389,7 @@ class SearchBar(CommandBarBase):
             pre.Refresh()
 
     def GetConfigKey(self):
-        """Get the key to use for the layout config persistance.
+        """Get the key to use for the layout config persistence.
         @return: string
 
         """
@@ -448,7 +451,7 @@ class GotoLineBar(CommandBarBase):
 
 class CommandExecuter(eclib.CommandEntryBase):
     """Part of the Vi emulation, opens a minibuffer to execute EX commands.
-    @note: based on search ctrl so we get the nice roudned edges on wxmac.
+    @note: based on search ctrl so we get the nice rounded edges on wxmac.
 
     """
     RE_GO_BUFFER = re.compile('[0-9]*[nN]{1,1}')
@@ -475,12 +478,17 @@ class CommandExecuter(eclib.CommandEntryBase):
         else:
             self._popup = PopupWinList(self)
 
+        self.Bind(wx.EVT_WINDOW_DESTROY, self.OnDestroy, self)
         self.Bind(ed_event.EVT_NOTIFY, self.OnPopupNotify)
+
+        # Message handlers
         ed_msg.Subscribe(self._UpdateCwd, ed_msg.EDMSG_UI_NB_CHANGED)
         ed_msg.Subscribe(self._UpdateCwd, ed_msg.EDMSG_FILE_SAVED)
 
-    def __del__(self):
-        ed_msg.Unsubscribe(self._UpdateCwd)
+    def OnDestroy(self, evt):
+        if evt.GetId() == self.GetId():
+            ed_msg.Unsubscribe(self._UpdateCwd)
+        evt.Skip()
 
     def _AdjustSize(self):
         """Checks width of text as its added and dynamically resizes
@@ -763,12 +771,17 @@ class CommandExecuter(eclib.CommandEntryBase):
 
         # We expanded head, so trim the suggestion list of its head
         # so we can add the tail of the suggestion back to the original head
-        candidates = [os.path.basename(p) for p in os.listdir(head)
-                      if p.startswith(tail)]
-        candidates = [append_slash(os.path.join(os.path.dirname(path), cand))
-                      for cand in candidates]
-        if not files:
-            candidates = [cand for cand in candidates if os.path.isdir(cand)]
+        try:
+            candidates = [os.path.basename(p) for p in os.listdir(head)
+                          if p.startswith(tail)]
+            candidates = [append_slash(os.path.join(os.path.dirname(path), cand))
+                          for cand in candidates]
+            if not files:
+                candidates = [cand for cand in candidates if os.path.isdir(cand)]
+        except OSError:
+            ed_msg.PostMessage(ed_msg.EDMSG_UI_SB_TXT,
+                               (ed_glob.SB_INFO, _("Invalid Path")))
+            candidates = list()
 
         return sorted(list(set(candidates)))
 
@@ -812,7 +825,7 @@ class CommandExecuter(eclib.CommandEntryBase):
 
     def OnKeyDown(self, evt):
         """Records the key sequence that has been entered and
-        performs actions based on that keysequence.
+        performs actions based on that key sequence.
         @param evt: event that called this handler
 
         """
@@ -877,7 +890,7 @@ class CommandExecuter(eclib.CommandEntryBase):
         evt.Skip()
 
     def OnPopupNotify(self, evt):
-        """Recieve the selections from the popup list
+        """Receive the selections from the popup list
         @param evt: event that called this handler
 
         """
@@ -901,7 +914,7 @@ class CommandExecuter(eclib.CommandEntryBase):
         evt.Skip()
 
     def RestoreFocus(self):
-        """Restore focus and cursor postion
+        """Restore focus and cursor position
         @postcondition: ctrl has focus and cursor is moved to last position
 
         """
@@ -947,7 +960,7 @@ class LineCtrl(eclib.CommandEntryBase):
     """
     def __init__(self, parent, id_, get_doc, size=wx.DefaultSize):
         """Initializes the LineCtrl control and its attributes.
-        @param get_doc: callback method for retreiving a reference to the
+        @param get_doc: callback method for retrieving a reference to the
                         current document.
 
         """
@@ -1121,7 +1134,7 @@ class PopupList(wx.MiniFrame, PopupListBase):
         evt.Skip()
 
     def OnKeyUp(self, evt):
-        """Process key upevents in the control
+        """Process key up events in the control
         @param evt: event that called this handler
 
         """
