@@ -14,8 +14,8 @@ Text editor buffer view control for the main notebook
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_editv.py 63568 2010-02-27 18:52:47Z CJP $"
-__revision__ = "$Revision: 63568 $"
+__svnid__ = "$Id: ed_editv.py 66482 2010-12-28 21:57:50Z CJP $"
+__revision__ = "$Revision: 66482 $"
 
 #--------------------------------------------------------------------------#
 # Imports
@@ -31,7 +31,7 @@ import ed_tab
 from doctools import DocPositionMgr
 from profiler import Profile_Get
 from util import Log, SetClipboardText
-from ebmlib import GetFileModTime, ContextMenuManager
+from ebmlib import GetFileModTime, ContextMenuManager, GetFileName
 
 # External libs
 from extern.stcspellcheck import STCSpellCheck
@@ -79,6 +79,8 @@ class EdEditorView(ed_stc.EditraStc, ed_tab.EdTabBase):
         self._lprio = 0     # Idle event priority counter
         self._menu = ContextMenuManager()
         self._spell = STCSpellCheck(self, check_region=self.IsNonCode)
+        self._caret_w = 1
+        self._focused = True
         spref = Profile_Get('SPELLCHECK', default=dict())
         self._spell_data = dict(choices=list(),
                                 word=('', -1, -1),
@@ -104,6 +106,8 @@ class EdEditorView(ed_stc.EditraStc, ed_tab.EdTabBase):
         # Hide autocomp/calltips when window looses focus
         # TODO: decide on whether this belongs in base class or not
         self.Bind(wx.EVT_KILL_FOCUS, lambda evt: self.HidePopups())
+        self.Bind(wx.EVT_LEFT_UP, self.OnSetFocus)
+        self.Bind(wx.EVT_WINDOW_DESTROY, self.OnDestroy, self)
 
         ed_msg.Subscribe(self.OnConfigMsg,
                          ed_msg.EDMSG_PROFILE_CHANGE + ('SPELLCHECK',))
@@ -114,9 +118,10 @@ class EdEditorView(ed_stc.EditraStc, ed_tab.EdTabBase):
         ed_msg.Subscribe(self.OnConfigMsg,
                          ed_msg.EDMSG_PROFILE_CHANGE + ('SYNTAX',))
 
-    def __del__(self):
-        ed_msg.Unsubscribe(self.OnConfigMsg)
-        super(EdEditorView, self).__del__()
+    def OnDestroy(self, evt):
+        if evt.GetId() == self.GetId():
+            ed_msg.Unsubscribe(self.OnConfigMsg)
+        evt.Skip()
 
     #---- EdTab Methods ----#
 
@@ -134,6 +139,20 @@ class EdEditorView(ed_stc.EditraStc, ed_tab.EdTabBase):
         if self.IsLoading():
             return
 
+        # Handle hiding and showing the caret when the window gets loses focus
+        cfocus = self.FindFocus()
+        if not self._focused and cfocus is self:
+            # Focus has just returned to the window
+            self.SetCaretWidth(self._caret_w)
+            self._focused = True
+        elif self._focused and cfocus is not self:
+            cwidth = self.GetCaretWidth()
+            if cwidth > 0:
+                self._caret_w = cwidth
+            self.SetCaretWidth(0) # Hide the caret when not active
+            self._focused = False
+
+        # Check for changes to on disk file
         if not self._has_dlg and Profile_Get('CHECKMOD'):
             cfile = self.GetFileName()
             lmod = GetFileModTime(cfile)
@@ -230,6 +249,7 @@ class EdEditorView(ed_stc.EditraStc, ed_tab.EdTabBase):
         menu.Append(ed_glob.ID_CLOSE_OTHERS, _("Close Other Tabs"))
         menu.Append(ed_glob.ID_CLOSEALL, _("Close All"))
         menu.AppendSeparator()
+        menu.Append(ed_glob.ID_COPY_FILE, _("Copy Filename"))
         menu.Append(ed_glob.ID_COPY_PATH, _("Copy Full Path"))
         return menu
 
@@ -255,15 +275,27 @@ class EdEditorView(ed_stc.EditraStc, ed_tab.EdTabBase):
 
         """
         if self._ignore_del:
+            self._ignore_del = False
             return True
 
         result = True
         if self.GetModify():
             result = self.ModifySave()
             result = result in (wx.ID_YES, wx.ID_OK, wx.ID_NO)
+            if result:
+                self._ignore_del = True
 
         return result
 
+    def OnSetFocus(self, evt):
+        """Make sure that the currently selected tab is this one"""
+        evt.Skip()
+        parent = self.GetParent()
+        csel = parent.GetSelection()
+        idx = self.GetTabIndex()
+        if csel != idx:
+            parent.SetSelection(idx)
+
     def OnSpelling(self, buff, evt):
         """Context menu subscriber callback
         @param buff: buffer menu event happened in
@@ -285,9 +317,11 @@ class EdEditorView(ed_stc.EditraStc, ed_tab.EdTabBase):
     def OnTabMenu(self, evt):
         """Tab menu event handler"""
         e_id = evt.GetId()
-        if e_id == ed_glob.ID_COPY_PATH:
+        if e_id in (ed_glob.ID_COPY_PATH, ed_glob.ID_COPY_FILE):
             path = self.GetFileName()
             if path is not None:
+                if e_id == ed_glob.ID_COPY_FILE:
+                    path = GetFileName(path)
                 SetClipboardText(path)
         elif e_id == ed_glob.ID_MOVE_TAB:
             frame = wx.GetApp().OpenNewWindow()
