@@ -15,8 +15,8 @@ main Ui component of the editor that contains all the other components.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_main.py 66247 2010-11-23 19:49:55Z CJP $"
-__revision__ = "$Revision: 66247 $"
+__svnid__ = "$Id: ed_main.py 66685 2011-01-14 23:10:50Z CJP $"
+__revision__ = "$Revision: 66685 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -271,6 +271,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         # Frame
         self.Bind(wx.EVT_ACTIVATE, self.OnActivate)
         self.Bind(wx.EVT_CLOSE, self.OnClose)
+        self.Bind(wx.EVT_WINDOW_DESTROY, self.OnDestroy, self)
         self.Bind(ed_event.EVT_STATUS, self.OnStatus)
 
         # Find Dialog
@@ -290,10 +291,8 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         self._handlers['menu'].extend(addons.GetEventHandlers())
         self._handlers['ui'].extend(addons.GetEventHandlers(ui_evt=True))
         shelf = ed_shelf.Shelf(plgmgr)
-        shelf.Init(self)
-        self._handlers['ui'].extend(shelf.GetUiHandlers())
-        self._shelf = ed_shelf.Shelf.delegate
-        ed_shelf.Shelf.delegate = None
+        self._shelf = shelf.Init(self)
+        self._handlers['ui'].extend(shelf.GetUiHandlers(self._shelf))
 
         self.LOG("[ed_main][info] Loading Generator plugins")
         generator.Generator(plgmgr).InstallMenu(menbar.GetMenuByName("tools"))
@@ -313,8 +312,10 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
 
     __name__ = u"MainWindow"
 
-    def __del__(self):
-        ed_msg.Unsubscribe(self.OnUpdateFileHistory)
+    def OnDestroy(self, evt):
+        if evt.GetId() == self.GetId():
+            ed_msg.Unsubscribe(self.OnUpdateFileHistory)
+        evt.Skip()
 
     #---- End Private Member Functions/Variables ----#
 
@@ -636,6 +637,39 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         else:
             evt.Skip()
 
+    def SaveFile(self, tablbl, buf):
+        """Save the given page in the notebook
+        @param tablbl: main notebook tab label
+        @param buf: EdEditView instance
+        @note: intended for internal use! method signature may change
+
+        """
+        fname = ebmlib.GetFileName(buf.GetFileName())
+        if fname != u'':
+            fpath = buf.GetFileName()
+            result = buf.SaveFile(fpath)
+            self._last_save = fpath
+            if result:
+                self.PushStatusText(_("Saved File: %s") % fname, SB_INFO)
+            else:
+                err = buf.GetDocument().GetLastError()
+                self.PushStatusText(_("ERROR: %s") % err, SB_INFO)
+                ed_mdlg.SaveErrorDlg(self, fname, err)
+                buf.GetDocument().ResetAll()
+        else:
+            self.OnSaveAs(ID_SAVEAS, tablbl, buf)
+
+    def SaveCurrentBuffer(self):
+        """Save the file in the currently selected editor buffer"""
+        page = self.nb.GetSelection()
+        self.SaveFile(self.nb.GetPageText(page), self.nb.GetCurrentCtrl())
+
+    def SaveAllBuffers(self):
+        """Save all open editor buffers"""
+        for page in xrange(self.nb.GetPageCount()):
+            if isinstance(self.nb.GetPage(page), wx.stc.StyledTextCtrl):
+                self.SaveFile(self.nb.GetPageText(page), self.nb.GetPage(page))
+
     def OnSave(self, evt):
         """Save Current or All Buffers
         @param evt: Event fired that called this handler
@@ -643,40 +677,14 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
 
         """
         e_id = evt.GetId()
-        ctrls = list()
         if e_id == ID_SAVE:
-            page = self.nb.GetSelection()
-            ctrls = [(self.nb.GetPageText(page),
-                      self.nb.GetCurrentCtrl(), page)]
+            self.SaveCurrentBuffer()
         elif e_id == ID_SAVEALL:
-            # Collect all open editor buffers
-            for page in xrange(self.nb.GetPageCount()):
-                if issubclass(self.nb.GetPage(page).__class__,
-                                           wx.stc.StyledTextCtrl):
-                    ctrls.append((self.nb.GetPageText(page),
-                                  self.nb.GetPage(page), page))
+            self.SaveAllBuffers()
         else:
             evt.Skip()
             return
 
-        # TODO: detect when save fails due to encoding and prompt to
-        #       request an encoding from the user.
-        for ctrl in ctrls:
-            fname = ebmlib.GetFileName(ctrl[1].GetFileName())
-            if fname != '':
-                fpath = ctrl[1].GetFileName()
-                result = ctrl[1].SaveFile(fpath)
-                self._last_save = fpath
-                if result:
-                    self.PushStatusText(_("Saved File: %s") % fname, SB_INFO)
-                else:
-                    err = ctrl[1].GetDocument().GetLastError()
-                    self.PushStatusText(_("ERROR: %s") % err, SB_INFO)
-                    ed_mdlg.SaveErrorDlg(self, fname, err)
-                    ctrl[1].GetDocument().ResetAll()
-            else:
-                self.OnSaveAs(ID_SAVEAS, ctrl[0], ctrl[1])
-
     def OnSaveAs(self, evt, title=u'', page=None):
         """Save File Using a new/different name
         @param evt: Event fired that called this handler
