@@ -13,8 +13,8 @@ This class implements Editra's main notebook control.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_pages.py 66247 2010-11-23 19:49:55Z CJP $"
-__revision__ = "$Revision: 66247 $"
+__svnid__ = "$Id: ed_pages.py 66686 2011-01-14 23:13:08Z CJP $"
+__revision__ = "$Revision: 66686 $"
 
 #--------------------------------------------------------------------------#
 # Dependencies
@@ -65,7 +65,7 @@ class EdPages(aui.AuiNotebook):
                 aui.AUI_NB_ORDER_BY_ACCESS
         if wx.Platform == '__WXMAC__':
             style |= aui.AUI_NB_CLOSE_ON_TAB_LEFT
-        aui.AuiNotebook.__init__(self, parent, id_num, agwStyle=style)
+        super(EdPages, self).__init__(parent, id_num, agwStyle=style)
 
         # Notebook attributes
         self.LOG = wx.GetApp().GetLog()
@@ -105,6 +105,7 @@ class EdPages(aui.AuiNotebook):
         self.SetMinMaxTabWidth(125, 135)
 
         # Notebook Events
+        self.Bind(wx.EVT_WINDOW_DESTROY, self.OnDestroy, self)
         self.Bind(aui.EVT_AUINOTEBOOK_PAGE_CHANGING, self.OnPageChanging)
         self.Bind(aui.EVT_AUINOTEBOOK_PAGE_CHANGED, self.OnPageChanged)
         self.Bind(aui.EVT_AUINOTEBOOK_PAGE_CLOSE, self.OnPageClosing)
@@ -116,6 +117,7 @@ class EdPages(aui.AuiNotebook):
         self.Bind(aui.EVT_AUINOTEBOOK_TAB_RIGHT_UP, self.OnTabMenu)
         self.Bind(aui.EVT_AUINOTEBOOK_ALLOW_DND, self.OnAllowDnD)
         self.Bind(aui.EVT_AUINOTEBOOK_END_DRAG, self.OnDragFinished)
+        self.Bind(aui.EVT_AUINOTEBOOK_DRAG_DONE, self.OnDragFinished)
 
         self.Bind(wx.stc.EVT_STC_CHANGE, self.OnUpdatePageText)
         self.Bind(wx.EVT_MENU, self.OnMenu)
@@ -130,14 +132,15 @@ class EdPages(aui.AuiNotebook):
 
         # Add a blank page
         self.NewPage()
-        self._idletimer.Start(333) # Do idle checks 3 times a second
+        self._idletimer.Start(400)
 
     #---- End Init ----#
 
-    def __del__(self):
-        ed_msg.Unsubscribe(self.OnThemeChanged)
-        ed_msg.Unsubscribe(self.OnUpdatePosCache)
-        ed_msg.UnRegisterCallback(self.OnDocPointerRequest)
+    def OnDestroy(self, evt):
+        if evt.GetId() == self.GetId():
+            ed_msg.Unsubscribe(self.OnThemeChanged)
+            ed_msg.Unsubscribe(self.OnUpdatePosCache)
+            ed_msg.UnRegisterCallback(self.OnDocPointerRequest)
 
     #---- Function Definitions ----#
     
@@ -434,6 +437,7 @@ class EdPages(aui.AuiNotebook):
         dsource = evt.GetDragSource()
         if isinstance(dsource, EdPages):
             evt.Allow()
+            wx.CallAfter(self.UpdateIndexes)
 
     def OnDragFinished(self, evt):
         self.UpdateIndexes()
@@ -497,6 +501,7 @@ class EdPages(aui.AuiNotebook):
 
         """
         sel = evt.GetSelection()
+        self.LOG("[ed_pages][evt] OnMClickUp: %d" % sel)
         if sel == self.mdown:
             self.ClosePage()
         self.mdown = -1
@@ -851,12 +856,9 @@ class EdPages(aui.AuiNotebook):
 
         """
         current_page = self.GetSelection()
-        if current_page < 0:
-            return current_page
-
-        control = self.GetPage(current_page)
-#        control.SetFocus()
-        self.control = control
+        if current_page >= 0:
+            control = self.GetPage(current_page)
+            self.control = control
         return current_page
 
     def GotoPage(self, fname):
@@ -1021,9 +1023,10 @@ class EdPages(aui.AuiNotebook):
 
         """
         if wx.GetApp().IsActive():
-            page = self.GetCurrentPage()
-            if page is not None:
-                page.DoOnIdle()
+            for idx in range(self.GetPageCount()):
+                page = self.GetPage(idx)
+                if page is not None and page.IsShown():
+                    page.DoOnIdle()
 
     def OnPageChanging(self, evt):
         """Page changing event handler.
@@ -1056,7 +1059,6 @@ class EdPages(aui.AuiNotebook):
 
         # Get the window that is the current page
         window = self.GetPage(pg_num)
-#        window.SetFocus()
         self.control = window
 
         # Update Frame Title
@@ -1247,7 +1249,7 @@ class EdPages(aui.AuiNotebook):
         """
         # If icons preference has been disabled then clear all icons
         if not Profile_Get('TABICONS'):
-            for page in xrange(self.GetPageCount()):
+            for page in range(self.GetPageCount()):
                 super(EdPages, self).SetPageImage(page, -1)
         else:
             # Reload the image list with new icons from the ArtProvider
@@ -1267,7 +1269,7 @@ class EdPages(aui.AuiNotebook):
 
     def UpdateIndexes(self):
         """Update all page indexes"""
-        pages = [self.GetPage(page) for page in xrange(self.GetPageCount())]
+        pages = [self.GetPage(page) for page in range(self.GetPageCount())]
         for idx, page in enumerate(pages):
             page.SetTabIndex(idx)
 
