@@ -18,8 +18,8 @@ specific options such as commenting code.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_stc.py 66336 2010-12-05 22:07:51Z CJP $"
-__revision__ = "$Revision: 66336 $"
+__svnid__ = "$Id: ed_stc.py 66529 2011-01-03 03:09:57Z CJP $"
+__revision__ = "$Revision: 66529 $"
 
 #-------------------------------------------------------------------------#
 # Imports
@@ -136,7 +136,7 @@ class EditraStc(ed_basestc.EditraBaseStc):
         self.UpdateBaseStyles()
 
         # Other Settings
-        self.SetMouseDwellTime(800)
+        self.SetMouseDwellTime(900)
         self.UsePopUp(False)
 
         #self.Bind(wx.stc.EVT_STC_MACRORECORD, self.OnRecordMacro)
@@ -259,7 +259,7 @@ class EditraStc(ed_basestc.EditraBaseStc):
         Sends notifications for bookmark removal.
 
         """
-        super(EditraStc, self).RemoveAllBookmark()
+        super(EditraStc, self).RemoveAllBookmarks()
         mdata = dict(stc=self, added=False, line=-1)
         ed_msg.PostMessage(ed_msg.EDMSG_UI_STC_BOOKMARK, mdata)
 
@@ -652,8 +652,7 @@ class EditraStc(ed_basestc.EditraBaseStc):
             else:
                 evt.Skip()
 
-            if self.CallTipActive():
-                self.CallTipCancel()
+            self.CallTipCancel()
 
         elif self.VertEdit.Enabled:
             # XXX: handle column mode
@@ -723,8 +722,7 @@ class EditraStc(ed_basestc.EditraBaseStc):
 
         elif key_code in cmpl.GetCallTipCancel():
             evt.Skip()
-            if self.CallTipActive():
-                self.CallTipCancel()
+            self.CallTipCancel()
 #        elif key_code == wx.WXK_TAB and \
 #             True not in (evt.ControlDown(), evt.CmdDown(), 
 #                          evt.ShiftDown(), evt.AltDown()):
@@ -878,6 +876,13 @@ class EditraStc(ed_basestc.EditraBaseStc):
 
     def OnDwellStart(self, evt):
         """Callback hook for mouse dwell start"""
+        # Workaround issue where this event in incorrectly sent
+        # when the mouse has not dwelled within the buffer area
+        mpoint = wx.GetMousePosition()
+        brect = self.GetScreenRect()
+        if not brect.Contains(mpoint):
+            return
+
         position = evt.Position
         if not self._dwellsent and position >= 0:
             dwellword = self.GetWordFromPosition(position)[0]
@@ -909,8 +914,7 @@ class EditraStc(ed_basestc.EditraBaseStc):
         """Callback hook for mouse dwell end"""
         self._dwellsent = False
         ed_msg.PostMessage(ed_msg.EDMSG_UI_STC_DWELL_END)
-        if self.CallTipActive():
-            self.CallTipCancel()
+        self.CallTipCancel()
         evt.Skip()
 
     def OnMarginClick(self, evt):
@@ -1303,10 +1307,16 @@ class EditraStc(ed_basestc.EditraBaseStc):
         """
         return self.recording
 
-    def LineDelete(self): # pylint: disable-msg=W0221
-        """Delete the selected lines without modifying the clipboard"""
+    def GetSelectionLineStartEnd(self):
+        """Get the start and end positions of the lines in the current
+        fuzzy selection.
+        @return: tuple (int, int)
+
+        """
         sline = self.LineFromPosition(self.GetSelectionStart())
         eline = self.LineFromPosition(self.GetSelectionEnd())
+        last_line = self.GetLineCount() - 1
+        eol_len = len(self.GetEOLChar())
         if sline < eline:
             tstart = self.GetLineStartPosition(sline)
             tend = self.GetLineEndPosition(eline)
@@ -1314,8 +1324,26 @@ class EditraStc(ed_basestc.EditraBaseStc):
             tstart = self.GetLineStartPosition(eline)
             tend = self.GetLineEndPosition(sline)
 
-        self.SetTargetStart(tstart)
-        self.SetTargetEnd(tend + len(self.GetEOLChar()))
+        if eline == last_line and tstart != 0:
+            tstart -= eol_len
+        else:
+            tend += eol_len
+
+        return (max(tstart, 0), min(tend, self.GetLength()))
+
+    def LineCut(self): # pylint: disable-msg=W0221
+        """Cut the selected lines into the clipboard"""
+        start, end = self.GetSelectionLineStartEnd()
+        self.SetSelection(start, end)
+        self.BeginUndoAction()
+        self.Cut()
+        self.EndUndoAction()
+
+    def LineDelete(self): # pylint: disable-msg=W0221
+        """Delete the selected lines without modifying the clipboard"""
+        start, end = self.GetSelectionLineStartEnd()
+        self.SetTargetStart(start)
+        self.SetTargetEnd(end)
         self.BeginUndoAction()
         self.ReplaceTarget(u'')
         self.EndUndoAction()
