@@ -13,16 +13,17 @@ text buffer.
 """
 
 __author__ = "Hasan Aljudy"
-__cvsid__ = "$Id: ed_vim.py 60721 2009-05-23 01:24:30Z CJP $"
-__revision__ = "$Revision: 60721 $"
+__cvsid__ = "$Id: ed_vim.py 66531 2011-01-03 05:22:21Z CJP $"
+__revision__ = "$Revision: 66531 $"
 
 # ---------------------------------------------------------------------------- #
 # Imports
+import wx
 import re
 import string
 
 # Local Imports
-from ebmlib import Clipboard
+import ebmlib
 
 # ---------------------------------------------------------------------------- #
 
@@ -74,6 +75,7 @@ class EditraCommander(object):
 
     """
     def __init__(self, keyprocessor):
+        super(EditraCommander, self).__init__()
 
         # Attributes
         self.keyprocessor = keyprocessor
@@ -148,9 +150,14 @@ class EditraCommander(object):
         @param repeat: int
 
         """
+        cline = self.stc.GetCurrentLine()
+        lline = self.stc.GetLineCount() - 1
         self.GotoLineStart()
+        if cline == lline:
+            cpos = self.stc.GetCurrentPos() - len(self.stc.GetEOLChar())
+            cpos = max(0, cpos)
+            self.stc.GotoPos(cpos)
         self.PushCaret()
-        self.GotoLineStart()
         self.MoveDown(repeat)
         self.StartSelection()
         self.PopCaret()
@@ -242,7 +249,7 @@ class EditraCommander(object):
 
     def EndSelection(self):
         """Set the selection to start from the starting position as it was set
-        by StartSeletion to the current caret position
+        by StartSelection to the current caret position
 
         It doesn't matter whether the starting position is before or after the
         ending position
@@ -266,7 +273,9 @@ class EditraCommander(object):
 
     def GotoLine(self, line):
         """Goto the start of indentation of given line"""
-        pos = self.stc.PositionFromLine(line)
+        # PostionFromLine returns the position past the last character on the
+        # line. So need to look at previous line to get the correct position.
+        pos = self.stc.PositionFromLine(max(0,line-1))
         self._SetPos(pos)
         self.GotoIndentStart()
 
@@ -517,7 +526,7 @@ class EditraCommander(object):
         self._NextIdent(repeat)
 
     def PrevIdent(self, repeat=1):
-        """Find the previos occurance of identifier under cursor"""
+        """Find the previous occurrence of identifier under cursor"""
         self._NextIdent(repeat, back=True)
 
     def InsertText(self, text):
@@ -589,11 +598,11 @@ class EditraCommander(object):
 
     def SetRegister(self, reg='"'):
         """Set the current working clipboard (aka register) to given name"""
-        Clipboard.Switch(reg)
+        ebmlib.Clipboard.Switch(reg)
 
     def YankSelection(self):
         """Copy the current selection to the clipboard"""
-        Clipboard.Set(self.GetSelectedText())
+        ebmlib.Clipboard.Set(self.GetSelectedText())
 
     def DeleteSelection(self):
         """Yank selection and delete it"""
@@ -617,20 +626,23 @@ class EditraCommander(object):
         is set to True, then it's pasted on a new line above the current line
 
         """
-        text = Clipboard.Get()
+        text = ebmlib.Clipboard.Get()
         if not text:
             return
 
-        if self._IsLine(text):
+        bIsLine = self._IsLine(text)
+        if bIsLine:
             self.GotoLineStart()
             if not before:
                 self.MoveDown()
 
+        self.BeginUndoAction()
         if self.HasSelection():
             # paste over selection, if any
             self.stc.Clear()
+        elif not bIsLine:
+            self.stc.CharRight()
 
-        self.BeginUndoAction()
         for i in range(repeat):
             self.InsertText(text)
         self.EndUndoAction()
@@ -967,7 +979,7 @@ def Dot(editor, repeat, cmd):
     if editor.IsInsertMode():
         editor.NormalMode() # in case it was a 'c' command
 
-@vim_parser('hjkl', is_motion=True)
+@vim_parser('hjkl\r \x08', is_motion=True)
 def Arrows(editor, repeat, cmd):
     """Basic arrow movement in vim.
     @see: vim_parser
@@ -978,6 +990,9 @@ def Arrows(editor, repeat, cmd):
             u'j': editor.MoveDown,
             u'k': editor.MoveUp,
             u'l': editor.MoveRight,
+            u'\r': editor.MoveDown,
+            u' ' : editor.MoveRight,
+            u'\x08' : editor.MoveLeft
           }
     cmd_map[cmd](repeat)
 
@@ -1115,11 +1130,13 @@ def Change(editor, repeat, cmd):
         cmd, motion = cmd[0], cmd[1:]
         if motion.isdigit():
             return ret(NeedMore)
+
         motion_repeat, motion_cmd = SplitRepeat(motion)
         if motion_repeat:
             repeat = repeat * motion_repeat
+
         if motion_cmd == cmd:
-            # Oerate on whole line
+            # Operate on whole line
             line_motion = True
             editor.PushColumn()
             editor.SelectLines(repeat)
@@ -1196,7 +1213,11 @@ def Reg(editor, repeat, cmd):
         return NeedMore
 
     cmd, char = cmd
-    editor.SetRegister(char)
+    try:
+        editor.SetRegister(char)
+    except ebmlib.ClipboardException:
+        # Attempted to switch to invalid register
+        wx.Bell()
 
 @vim_parser(u'r')
 def ReplaceChar(editor, repeat, cmd):
