@@ -15,8 +15,8 @@ Provides a dialog for downloading, installing and configuring plugins or Editra.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__cvsid__ = "$Id: plugdlg.py 66110 2010-11-10 22:27:34Z CJP $"
-__revision__ = "$Revision: 66110 $"
+__cvsid__ = "$Id: plugdlg.py 66690 2011-01-15 20:21:35Z CJP $"
+__revision__ = "$Revision: 66690 $"
 
 #-----------------------------------------------------------------------------#
 # Imports
@@ -138,12 +138,15 @@ class PluginDialog(wx.Frame):
         # Event Handlers
         self.Bind(eclib.EVT_SB_PAGE_CHANGING, self.OnPageChanging)
         self.Bind(wx.EVT_CLOSE, self.OnClose)
+        self.Bind(wx.EVT_WINDOW_DESTROY, self.OnDestroy, self)
 
         # Message Handlers
         ed_msg.Subscribe(self.OnThemeChange, ed_msg.EDMSG_THEME_CHANGED)
 
-    def __del__(self):
-        ed_msg.Unsubscribe(self.OnThemeChange)
+    def OnDestroy(self, evt):
+        if evt.GetId() == self.GetId():
+            ed_msg.Unsubscribe(self.OnThemeChange)
+        evt.Skip()
 
     def __InitImageList(self):
         """Initialize the segmentbooks image list"""
@@ -367,7 +370,9 @@ class ConfigPanel(eclib.ControlBox):
 
             pdata = PluginData()
             pdata.SetName(item)
-            desc = getattr(mod, '__doc__', _("No Description Available"))
+            desc = getattr(mod, '__doc__', None)
+            if not isinstance(desc, basestring):
+                desc = _("No Description Available")
             pdata.SetDescription(desc.strip())
             pdata.SetAuthor(getattr(mod, '__author__', _("Unknown")))
             pdata.SetVersion(version)
@@ -416,14 +421,14 @@ class ConfigPanel(eclib.ControlBox):
                 item = dist.project_name
                 version = dist.version
             else:
-                version = str(getattr(mod, '__version__', _("Unknown")))
+                version = unicode(getattr(mod, '__version__', _("Unknown")))
 
             pin = PluginData()
             pin.SetName(item)
             pin.SetAuthor(getattr(mod, '__author__', _("Unknown")))
             pin.SetVersion(version)
             pin.SetDist(dist)
-            pbi = PluginErrorItem(self._list, pin, bmp, item)
+            pbi = PluginErrorItem(self._list, pin, msg, bmp=bmp)
 
             self._list.AppendItem(pbi)
             self._list.Thaw()
@@ -1112,21 +1117,22 @@ class PBDownloadItem(PBPluginItem):
 
 class PluginErrorItem(eclib.PanelBoxItemBase):
     """PanelBox Item to display configuration information about a plugin."""
-    def __init__(self, parent, bmp,
-                 title=u'Plugin Name', version=u'0.0',
-                 msg=u'Description', auth='John Doe'):
+    def __init__(self, parent, pdata, msg, bmp):
         """Create the PanelBoxItem
         @param parent: L{PanelBox}
+        @param pdata: PluginData
+        @param msg: error msg
+        @param bmp: Bitmap
 
         """
         super(PluginErrorItem, self).__init__(parent)
 
         # Attributes
         self._bmp = bmp
-        self._title = wx.StaticText(self, label=title)
-        self._version = wx.StaticText(self, label=version)
+        self._title = wx.StaticText(self, label=pdata.GetName())
+        self._version = wx.StaticText(self, label=pdata.GetVersion())
         self._msg = wx.StaticText(self, label=msg)
-        self._auth = wx.StaticText(self, label=_("Author: %s") % auth)
+        self._auth = wx.StaticText(self, label=_("Author: %s") % pdata.GetAuthor())
 
         # Setup
         font = self._title.GetFont()
