@@ -16,8 +16,8 @@ and setting of the program by setting values in the Profile.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: prefdlg.py 66335 2010-12-05 21:58:53Z CJP $"
-__revision__ = "$Revision: 66335 $"
+__svnid__ = "$Id: prefdlg.py 66482 2010-12-28 21:57:50Z CJP $"
+__revision__ = "$Revision: 66482 $"
 
 #----------------------------------------------------------------------------#
 # Dependancies
@@ -200,12 +200,15 @@ class PrefTools(eclib.SegmentBook):
         # Event Handlers
         self.Bind(eclib.EVT_SB_PAGE_CHANGED, self.OnPageChanged)
         self.Bind(eclib.EVT_SB_PAGE_CHANGING, self.OnPageChanging)
+        self.Bind(wx.EVT_WINDOW_DESTROY, self.OnDestroy, self)
 
         # Message Handlers
         ed_msg.Subscribe(self.OnThemeChange, ed_msg.EDMSG_THEME_CHANGED)
 
-    def __del__(self):
-        ed_msg.Unsubscribe(self.OnThemeChange)
+    def OnDestroy(self, evt):
+        if evt.GetId() == self.GetId():
+            ed_msg.Unsubscribe(self.OnThemeChange)
+        evt.Skip()
 
     def __InitImgList(self):
         """Setup the image list for the SegmentBook"""
