@@ -20,8 +20,8 @@ happen during run time.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: profiler.py 65751 2010-10-03 21:24:06Z CJP $"
-__revision__ = "$Revision: 65751 $"
+__svnid__ = "$Id: profiler.py 66449 2010-12-26 05:09:16Z CJP $"
+__revision__ = "$Revision: 66449 $"
 
 #--------------------------------------------------------------------------#
 # Imports
@@ -421,6 +421,8 @@ def GetProfileStr():
     profile = reader.readline()
     profile = profile.split("\n")[0] # strip newline from end
     reader.close()
+    if not os.path.isabs(profile):
+        profile = CONFIG['PROFILE_DIR'] + profile
     return profile
 
 def ProfileIsCurrent():
@@ -484,8 +486,7 @@ def UpdateProfileLoader():
         Profile_Set('MYPROFILE', prof_name)
 
     # Use just the relative profile name for local(portable) config paths
-    if CONFIG['ISLOCAL']:
-        prof_name = os.path.basename(prof_name)
+    prof_name = os.path.basename(prof_name)
 
     writer.write(prof_name)
     writer.write(u"\nVERSION\t" + VERSION)
