@@ -14,15 +14,16 @@ is the L{UpdateProgress} bar it displays the progress of the network action and
 provides a higher level interface into the L{UpdateService}.
 
 @summary: Utilities and controls for updating Editra
+@todo: This module could benefit from a bit of a re-write...
 
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: updater.py 66214 2010-11-19 22:43:00Z CJP $"
-__revision__ = "$Revision: 66214 $"
+__svnid__ = "$Id: updater.py 66517 2011-01-01 18:52:26Z CJP $"
+__revision__ = "$Revision: 66517 $"
 
 #--------------------------------------------------------------------------#
-# Dependancies
+# Dependencies
 import os
 import sys
 import stat
@@ -65,7 +66,7 @@ class UpdateService(object):
     def __GetUrlHandle(self, url):
         """Gets a file handle for the given url. The caller is responsible for
         closing the handle.
-        @requires: network conection
+        @requires: network connection
         @param url: url to get page from
         @return: all text from the given url
 
@@ -131,12 +132,12 @@ class UpdateService(object):
         """Parses the project website front page for the most
         recent version of the program.
         @requires: network connection
-        @return: verision number of latest available program
+        @return: version number of latest available program
 
         """
         page = self.GetPageText(ed_glob.HOME_PAGE + "/version.php?check=True")
         found = re.findall(RE_VERSION, page)
-        if False:#len(found):
+        if len(found):
             return found[0] # Should be the first/only match found
         else:
             util.Log("[updater][warn] UpdateService.GetCurrentVersionStr "
@@ -248,7 +249,7 @@ class UpdateThread(threading.Thread):
         @param jobId: job identification id will be set as event id on finish
 
         """
-        threading.Thread.__init__(self)
+        super(UpdateThread, self).__init__()
 
         # Attributes
         self.parent = parent
@@ -295,19 +296,22 @@ class UpdateProgress(wx.Gauge, UpdateService):
             self.SetWindowVariant(wx.WINDOW_VARIANT_LARGE)
 
         #---- Bind Events ----#
+        self.Bind(wx.EVT_WINDOW_DESTROY, self.OnDestroy, self)
         self.Bind(wx.EVT_TIMER, self.OnUpdate, id = self.ID_TIMER)
 
         # Disable bar till caller is ready to use it
         self.Disable()
 
-    def __del__(self):
+    def OnDestroy(self, evt):
         """Cleans up when the control is destroyed
         @postcondition: if timer is running it is stopped before deletion
 
         """
-        if self._timer.IsRunning():
-            self.LOG("[updater][info]UpdateProgress: __del__, stopped timer")
-            self._timer.Stop()
+        if evt.GetId() == self.GetId():
+            if self._timer.IsRunning():
+                self.LOG("[updater][info]UpdateProgress: __del__, stopped timer")
+                self._timer.Stop()
+        evt.Skip()
 
     def Abort(self):
         """Overides the UpdateService abort function
@@ -553,7 +557,7 @@ class DownloadDialog(wx.Frame):
         @param title: Title of dialog
 
         """
-        wx.Frame.__init__(self, parent, id_, title, style=style)
+        super(DownloadDialog, self).__init__(parent, id_, title, style=style)
         util.SetWindowIcon(self)
 
         #---- Attributes/Objects ----#
@@ -606,16 +610,19 @@ class DownloadDialog(wx.Frame):
         #---- Bind Events ----#
         self.Bind(wx.EVT_BUTTON, self.OnButton)
         self.Bind(wx.EVT_CLOSE, self.OnClose)
+        self.Bind(wx.EVT_WINDOW_DESTROY, self.OnDestroy, self)
         self.Bind(wx.EVT_TIMER, self.OnUpdate, id=self.ID_TIMER)
 
-    def __del__(self):
+    def OnDestroy(self, evt):
         """Cleans up on exit
         @postcondition: if timer was running it is stopped
 
         """
-        if self._timer.IsRunning():
-            self.LOG('[updater][info] DownloadDialog: __del__ Timer Stopped')
-            self._timer.Stop()
+        if evt.GetId() == self.GetId():
+            if self._timer.IsRunning():
+                self.LOG('[updater][info] DownloadDialog: __del__ Timer Stopped')
+                self._timer.Stop()
+        evt.Skip()
 
     def CalcDownRate(self):
         """Calculates and returns the approximate download rate
@@ -698,4 +705,4 @@ class DownloadDialog(wx.Frame):
         wx.GetApp().RegisterWindow(repr(self), self, True)
         self._timer.Start(1000) # One pulse every second
         self._progress.DownloadUpdates()
-        wx.Frame.Show(self)
+        super(DownloadDialog, self).Show()
